AbstractFirebaseFunctionLoaderFactory<I, T extends WithId<I>, F extends AbstractFilter> class
abstract
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
byIdBloc(I id)
→ ModelLoaderById<I, T>
-
inherited
-
clear()
→ Future<void>
-
Deletes all loaders.
inherited
-
clearFrozenLoaders()
→ Future<void>
-
Empties all frozen loaders but not disposes them.
inherited
-
createFrozenByIdBloc(I id)
→ ModelLoaderById<I, T>
-
inherited
-
createFrozenListBloc(F filter)
→ ListLazyLoader<T>
-
inherited
-
createFrozenListLazyLoader(F filter)
→ CloudFunctionFrozenListLazyLoader<T, F>
-
Creates a lazy loader for the objects matching the
filter
that is not self-updated when the data changes at the origin.
-
createFrozenModelByFilterBloc(F filter)
→ ModelLoaderByFilter<I, T>
-
inherited
-
createFrozenModelLoaderByFilter(F filter)
→ ModelLoaderByFilter<I, T>
-
Creates a loader for a single object by
filter that is not self-updated
when the data changes at the origin.
-
createFrozenModelLoaderById(I id)
→ ModelLoaderById<I, T>
-
Creates a loader for a single object by
id that is not self-updated
when the data changes at the origin.
-
createLiveByIdBloc(I id)
→ ModelLoaderById<I, T>
-
inherited
-
createLiveListBloc(F filter)
→ ListLazyLoader<T>
-
inherited
-
createLiveListLazyLoader(F filter)
→ ListLazyLoader<T>
-
Creates a lazy loader for the objects matching the
filter
that is self-updated when the data changes at the origin.
-
createLiveModelByFilterBloc(F filter)
→ ModelLoaderByFilter<I, T>
-
inherited
-
createLiveModelLoaderByFilter(F filter)
→ ModelLoaderByFilter<I, T>
-
Creates a loader for a single object by
filter that is self-updated
when the data changes at the origin.
-
createLiveModelLoaderById(I id)
→ ModelLoaderById<I, T>
-
Creates a loader for a single object by
id that is self-updated
when the data changes at the origin.
-
denormalize(Map<String, dynamic> map)
→ Future<T>
-
-
denormalizeBase(Map<String, dynamic> map)
→ Future<T>
-
-
frozenByIdBloc(I id)
→ ModelLoaderById<I, T>
-
inherited
-
frozenListBloc(F filter)
→ ListLazyLoader<T>
-
inherited
-
frozenListLazyLoader(F filter)
→ ListLazyLoader<T>
-
Creates a lazy loader for the objects matching the
filter
that is not self-updated when the data changes at the origin.
inherited
-
frozenModelByFilterBloc(F filter)
→ ModelLoaderByFilter<I, T>
-
inherited
-
frozenModelLoaderByFilter(F filter)
→ ModelLoaderByFilter<I, T>
-
Returns a loader for a single object by
filter that is not self-updated
when the data changes at the origin.
inherited
-
frozenModelLoaderById(I id)
→ ModelLoaderById<I, T>
-
Returns a loader for a single object by
id that is not self-updated
when the data changes at the origin.
inherited
-
listBloc(F filter)
→ ListLazyLoader<T>
-
inherited
-
listLazyLoader(F filter)
→ ListLazyLoader<T>
-
Returns a lazy loader for the objects matching the
filter.
Returns a self-updated loader if possible, or a frozen one otherwise.
inherited
-
liveByIdBloc(I id)
→ ModelLoaderById<I, T>
-
inherited
-
liveListBloc(F filter)
→ ListLazyLoader<T>
-
inherited
-
liveListLazyLoader(F filter)
→ ListLazyLoader<T>
-
Creates a lazy loader for the objects matching the
filter
that is self-updated when the data changes at the origin.
inherited
-
liveModelByFilterBloc(F filter)
→ ModelLoaderByFilter<I, T>
-
inherited
-
liveModelLoaderByFilter(F filter)
→ ModelLoaderByFilter<I, T>
-
Returns a loader for a single object by
filter that is self-updated
when the data changes at the origin.
inherited
-
liveModelLoaderById(I id)
→ ModelLoaderById<I, T>
-
Returns a loader for a single object by
id that is self-updated
when the data changes at the origin.
inherited
-
modelByFilterBloc(F filter)
→ ModelLoaderByFilter<I, T>
-
inherited
-
modelLoaderByFilter(F filter)
→ ModelLoaderByFilter<I, T>
-
Returns a loader for a single object by
filter.
Returns a self-updated loader if possible, or a frozen one otherwise.
inherited
-
modelLoaderById(I id)
→ ModelLoaderById<I, T>
-
Returns a loader for a single object by
id.
Returns a self-updated loader if possible, or a frozen one otherwise.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(Object error, StackTrace trace)
→ void
-
Prints
error and trace.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited