liveModelLoaderById method
ModelLoaderById<I, T>
liveModelLoaderById(
- I id
inherited
Returns a loader for a single object by id that is self-updated
when the data changes at the origin.
The loader is cached for future calls with the same ID.
Implementation
ModelLoaderById<I, T> liveModelLoaderById(I id) {
final existing = _liveModelById[id];
if (existing != null) {
return existing;
}
final result = createLiveModelLoaderById(id);
_liveModelById[id] = result;
return result;
}